==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_entities/standardwochild_001/StandardWOChild.java <==

package net.datastream.schemas.mp_entities.standardwochild_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PRIORITY;
import net.datastream.schemas.mp_fields.STANDARDWOCHILDID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STANDARDWOCHILDID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NEWSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OLDSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRIGGERSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRIGGERSTEP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DURATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRIORITY" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "standardwochildid",
    "newstatus",
    "oldstatus",
    "triggersequence",
    "triggerstep",
    "duration",
    "priority"
})
@XmlRootElement(name = "StandardWOChild")
public class StandardWOChild {

    @XmlElement(name = "STANDARDWOCHILDID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STANDARDWOCHILDID_Type standardwochildid;
    @XmlElement(name = "NEWSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type newstatus;
    @XmlElement(name = "OLDSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type oldstatus;
    @XmlElement(name = "TRIGGERSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long triggersequence;
    @XmlElement(name = "TRIGGERSTEP", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long triggerstep;
    @XmlElement(name = "DURATION", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long duration;
    @XmlElement(name = "PRIORITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected PRIORITY priority;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété standardwochildid.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDWOCHILDID_Type }
     *     
     */
    public STANDARDWOCHILDID_Type getSTANDARDWOCHILDID() {
        return standardwochildid;
    }

    /**
     * Définit la valeur de la propriété standardwochildid.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDWOCHILDID_Type }
     *     
     */
    public void setSTANDARDWOCHILDID(STANDARDWOCHILDID_Type value) {
        this.standardwochildid = value;
    }

    /**
     * Obtient la valeur de la propriété newstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getNEWSTATUS() {
        return newstatus;
    }

    /**
     * Définit la valeur de la propriété newstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setNEWSTATUS(STATUS_Type value) {
        this.newstatus = value;
    }

    /**
     * Obtient la valeur de la propriété oldstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getOLDSTATUS() {
        return oldstatus;
    }

    /**
     * Définit la valeur de la propriété oldstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setOLDSTATUS(STATUS_Type value) {
        this.oldstatus = value;
    }

    /**
     * Obtient la valeur de la propriété triggersequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getTRIGGERSEQUENCE() {
        return triggersequence;
    }

    /**
     * Définit la valeur de la propriété triggersequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setTRIGGERSEQUENCE(Long value) {
        this.triggersequence = value;
    }

    /**
     * Obtient la valeur de la propriété triggerstep.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getTRIGGERSTEP() {
        return triggerstep;
    }

    /**
     * Définit la valeur de la propriété triggerstep.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setTRIGGERSTEP(Long value) {
        this.triggerstep = value;
    }

    /**
     * Obtient la valeur de la propriété duration.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getDURATION() {
        return duration;
    }

    /**
     * Définit la valeur de la propriété duration.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setDURATION(Long value) {
        this.duration = value;
    }

    /**
     * Obtient la valeur de la propriété priority.
     * 
     * @return
     *     possible object is
     *     {@link PRIORITY }
     *     
     */
    public PRIORITY getPRIORITY() {
        return priority;
    }

    /**
     * Définit la valeur de la propriété priority.
     * 
     * @param value
     *     allowed object is
     *     {@link PRIORITY }
     *     
     */
    public void setPRIORITY(PRIORITY value) {
        this.priority = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_entities/standardwochild_001/StandardWOChild.java <==

package net.datastream.schemas.mp_entities.standardwochild_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PRIORITY;
import net.datastream.schemas.mp_fields.STANDARDWOCHILDID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STANDARDWOCHILDID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NEWSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OLDSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRIGGERSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRIGGERSTEP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DURATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRIORITY" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "standardwochildid",
    "newstatus",
    "oldstatus",
    "triggersequence",
    "triggerstep",
    "duration",
    "priority"
})
@XmlRootElement(name = "StandardWOChild")
public class StandardWOChild {

    @XmlElement(name = "STANDARDWOCHILDID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STANDARDWOCHILDID_Type standardwochildid;
    @XmlElement(name = "NEWSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type newstatus;
    @XmlElement(name = "OLDSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type oldstatus;
    @XmlElement(name = "TRIGGERSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long triggersequence;
    @XmlElement(name = "TRIGGERSTEP", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long triggerstep;
    @XmlElement(name = "DURATION", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long duration;
    @XmlElement(name = "PRIORITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected PRIORITY priority;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the standardwochildid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDWOCHILDID_Type }
     *     
     */
    public STANDARDWOCHILDID_Type getSTANDARDWOCHILDID() {
        return standardwochildid;
    }

    /**
     * Sets the value of the standardwochildid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDWOCHILDID_Type }
     *     
     */
    public void setSTANDARDWOCHILDID(STANDARDWOCHILDID_Type value) {
        this.standardwochildid = value;
    }

    /**
     * Gets the value of the newstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getNEWSTATUS() {
        return newstatus;
    }

    /**
     * Sets the value of the newstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setNEWSTATUS(STATUS_Type value) {
        this.newstatus = value;
    }

    /**
     * Gets the value of the oldstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getOLDSTATUS() {
        return oldstatus;
    }

    /**
     * Sets the value of the oldstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setOLDSTATUS(STATUS_Type value) {
        this.oldstatus = value;
    }

    /**
     * Gets the value of the triggersequence property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getTRIGGERSEQUENCE() {
        return triggersequence;
    }

    /**
     * Sets the value of the triggersequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setTRIGGERSEQUENCE(Long value) {
        this.triggersequence = value;
    }

    /**
     * Gets the value of the triggerstep property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getTRIGGERSTEP() {
        return triggerstep;
    }

    /**
     * Sets the value of the triggerstep property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setTRIGGERSTEP(Long value) {
        this.triggerstep = value;
    }

    /**
     * Gets the value of the duration property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getDURATION() {
        return duration;
    }

    /**
     * Sets the value of the duration property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setDURATION(Long value) {
        this.duration = value;
    }

    /**
     * Gets the value of the priority property.
     * 
     * @return
     *     possible object is
     *     {@link PRIORITY }
     *     
     */
    public PRIORITY getPRIORITY() {
        return priority;
    }

    /**
     * Sets the value of the priority property.
     * 
     * @param value
     *     allowed object is
     *     {@link PRIORITY }
     *     
     */
    public void setPRIORITY(PRIORITY value) {
        this.priority = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
